==> kdenlive-0.7.tar.gz: kdenlive-0.7/src/complexparameter.h <==
/***************************************************************************
                          complexparameter.h  -  description
                             -------------------
    begin                : Feb 15 2008
    copyright            : (C) 2008 by Marco Gittler
    email                : g.marco@freenet.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef COMPLEXPARAM_H
#define COMPLEXPARAM_H

#include <KIcon>

#include "ui_keyframewidget_ui.h"

class EffectsList;
class ClipItem;

class ComplexParameter : public QWidget {
    Q_OBJECT

public:
    ComplexParameter(QWidget *parent = 0);
    QDomElement getParamDesc();
private:
    int activeRow;
    QList<QDomElement> effects;
    Ui::KeyframeWidget_UI ui;
    ClipItem* clipref;
    void setupListView();
    void updateButtonStatus();
    QMap<QString, EffectsList*> effectLists;

    QDomElement param;
public slots:
    void slotSetMoveX();
    void slotSetMoveY();
    void slotSetNew();
    void slotSetHelp();
    void slotShowInTimeline();
    void slotParameterChanged(const QString&);
    void itemSelectionChanged();
    void setupParam(const QDomElement&, const QString& paramName, int, int);
    void slotUpdateEffectParams(QDomElement e);
    void slotUpdateParameterList(QStringList);
signals:
    void transferParamDesc(const QDomElement&, const QString&, int , int);
    void removeEffect(ClipItem*, QDomElement);
    void updateClipEffect(ClipItem*, QDomElement);
    void parameterChanged();

};

#endif

==> kdenlive-0.7.7.1.tar.gz: kdenlive-0.7.7.1/src/complexparameter.h <==
/***************************************************************************
                          complexparameter.h  -  description
                             -------------------
    begin                : Feb 15 2008
    copyright            : (C) 2008 by Marco Gittler
    email                : g.marco@freenet.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef COMPLEXPARAM_H
#define COMPLEXPARAM_H

#include <KIcon>

#include "ui_keyframewidget_ui.h"

class EffectsList;
class ClipItem;

class ComplexParameter : public QWidget
{
    Q_OBJECT

public:
    ComplexParameter(QWidget *parent = 0);
    QDomElement getParamDesc();
private:
    Ui::KeyframeWidget_UI m_ui;
    QDomElement m_param;
    void setupListView();
    void updateButtonStatus();

public slots:
    void slotSetMoveX();
    void slotSetMoveY();
    void slotSetNew();
    void slotSetHelp();
    void slotShowInTimeline();
    void slotParameterChanged(const QString&);
    void itemSelectionChanged();
    void setupParam(const QDomElement, const QString& paramName, int, int);
    void slotUpdateEffectParams(QDomElement e);
    void slotUpdateParameterList(QStringList);
signals:
    void removeEffect(ClipItem*, QDomElement);
    void updateClipEffect(ClipItem*, QDomElement);
    void parameterChanged();

};

#endif
